==> nextcloud-15.0.5p1.tgz: nextcloud/apps/updatenotification/l10n/nl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Update notifications" : "Bijwerken meldingen",
    "Channel updated" : "Kanaal bijgewerkt",
    "The update server could not be reached since %d days to check for new updates." : "De updateserver kon sinds %d dagen niet meer worden bereikt om op updates te controleren.",
    "Please check the Nextcloud and server log files for errors." : "Controleer de Nextcloud en server logbestanden op fouten.",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for %1$s to version %2$s is available." : "Update voor %1$s naar versie %2$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "Update notification" : "Bijwerkmelding",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Toont updatemeldingen voor Nextcloud en zorgt voor SSO voor de updater.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "De versie die je gebruikt, wordt niet langer ondersteund. Zorg ervoor om zo snel mogelijk bij te werken naar een ondersteunde versie.",
    "Apps missing updates" : "Apps met ontbrekende updates",
    "View in store" : "Bekijk in winkel",
    "Apps with available updates" : "Apps met beschikbare updates",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "What's new?" : "Wat is nieuw?",
    "The update check is not yet finished. Please refresh the page." : "De update controle is niet afgerond. Ververs de pagina.",
    "Your version is up to date." : "Je versie is up to date.",
    "A non-default update server is in use to be checked for updates:" : "Een niet-standaard updateserver is in gebruik om te worden gecontroleerd op updates:",
    "Update channel:" : "Bijwerkkanaal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Je kan altijd naar een nieuwere versie, maar je kan nooit terug naar een oudere stabielere versie.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Houd er rekening mee dat het enige tijd kan duren voordat na een nieuwe versie hier verschijnt. We verspreiden nieuwe versies over de tijd aan onze gebruikers en soms slaan we een versie over als er problemen zijn gevonden.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notification for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Er is een nieuwe versie beschikbaar: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Gecontroleerd op {lastCheckedDate}",
    "Checking apps for compatible updates" : "Apps controleren op compatibele updates",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Zorg ervoor dat je in config.php <samp>appstoreenabled</samp> niet op 'false' zet.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Kan niet verbinden met de appstore of de appstore gaf geen updates terug. Zoek handmatig naar updates of verifieer dat je server internettoegang heeft en kan verbinden met de appstore.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Alle</strong> apps hebben een update voor deze versie beschikbaar",
    "View changelog" : "Bekijk wijzigingenoverzicht",
    "Stable" : "Stabiel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "De meest recente stabiele versie. Het is geschikt voor normaal gebruik en werkt altijd bij naar de laatste hoofdversie.",
    "Production" : "Productie",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Geeft altijd de laatste aanpassingen, maar zal niet onmiddellijk naar de volgende hoofdversie gaan. Dat gebeurt wanneer de tweede sub versie (x.0.2) vrijgegeven wordt en alleen wanneer de huidige versie ook al op de laatste sub versie is.",
    "Beta" : "Test",
    "A pre-release version only for testing new features, not for production environments." : "Een vroeg vrijgegeven versie alleen voor het testen van nieuwe functies, niet voor produktie omgevingen.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> app heeft geen update voor deze versie beschikbaar","<strong>%n</strong> apps hebben geen update voor deze versie beschikbaar"],
    "Could not start updater, please try the manual update" : "Kon de updater niet starten, probeer de handmatige update",
    "A new version is available: %s" : "Er is een nieuwe versie beschikbaar: %s",
    "Checked on %s" : "Gecontroleerd op %s",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Je kunt altijd updaten naar een nieuwere versie of experimenteel kanaal. Maar terug naar een oudere versie of een stabieler kanaal is niet mogelijk.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>productie</strong> heeft altijd de laatste patches, maar de verwerkt de update naar de volgende grote release nog niet onmiddellijk.  Die update gebeurt meestal bij de tweede kleine release (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> is de recentste stabiele versie.  Het is geschikt voor regulier gebruik en zal altijd bijwerken naar de laatste grote versie.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>bèta</strong> is een versie om nieuwe functies uit te proberen, niet om te gebruiken in een productieomgeving."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/updatenotification/l10n/nl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} is beschikbaar. Meer informatie over het bijwerken.",
    "Channel updated" : "Kanaal bijgewerkt",
    "Update notifications" : "Bijwerken meldingen",
    "The update server could not be reached since %d days to check for new updates." : "De updateserver kon sinds %d dagen niet meer worden bereikt om op updates te controleren.",
    "Please check the Nextcloud and server log files for errors." : "Controleer de Nextcloud en server logbestanden op fouten.",
    "Update to %1$s is available." : "Update naar %1$s is beschikbaar.",
    "Update for %1$s to version %2$s is available." : "Update voor %1$s naar versie %2$s is beschikbaar.",
    "Update for {app} to version %s is available." : "Update voor {app} naar versie %s is beschikbaar.",
    "Update notification" : "Bijwerkmelding",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Toont updatemeldingen voor Nextcloud en zorgt voor SSO voor de updater.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "De versie die je gebruikt, wordt niet langer ondersteund. Zorg ervoor om zo snel mogelijk bij te werken naar een ondersteunde versie.",
    "Apps missing updates" : "Apps met ontbrekende updates",
    "View in store" : "Bekijk in winkel",
    "Apps with available updates" : "Apps met beschikbare updates",
    "Open updater" : "Open updater",
    "Download now" : "Download nu",
    "What's new?" : "Wat is nieuw?",
    "The update check is not yet finished. Please refresh the page." : "De update controle is niet afgerond. Ververs de pagina.",
    "Your version is up to date." : "Je versie is up to date.",
    "A non-default update server is in use to be checked for updates:" : "Een niet-standaard updateserver is in gebruik om te worden gecontroleerd op updates:",
    "Update channel:" : "Bijwerkkanaal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Je kan altijd naar een nieuwere versie, maar je kan nooit terug naar een oudere stabielere versie.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Houd er rekening mee dat het enige tijd kan duren voordat na een nieuwe versie hier verschijnt. We verspreiden nieuwe versies over de tijd aan onze gebruikers en soms slaan we een versie over als er problemen zijn gevonden.",
    "Notify members of the following groups about available updates:" : "Geef een melding over beschikbare updates aan leden van de volgende groepen:",
    "Only notification for app updates are available." : "Er zijn alleen meldingen voor apps beschikbaar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Het geselecteerde updatekanaal maakt overbodig om serverspecifieke meldingen apart te genereren.",
    "The selected update channel does not support updates of the server." : "Het geselecteerde updatekanaal ondersteunt geen updates voor de server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Er is een nieuwe versie beschikbaar: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Gecontroleerd op {lastCheckedDate}",
    "Checking apps for compatible updates" : "Apps controleren op compatibele updates",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Zorg ervoor dat je in config.php <samp>appstoreenabled</samp> niet op 'false' zet.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Kan niet verbinden met de appstore of de appstore gaf geen updates terug. Zoek handmatig naar updates of verifieer dat je server internettoegang heeft en kan verbinden met de appstore.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Alle</strong> apps hebben een update voor deze versie beschikbaar",
    "View changelog" : "Bekijk wijzigingenoverzicht",
    "Enterprise" : "Zakelijk",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Voor zakelijk gebruik. Biedt altijd de laatste patch level, maar zal niet meteen naar de laatste hoofdrelease bijwerken. Die update vindt pas plaatst nadat Nextcloud GmbH aanvullende hardening en tests voor grootschalige en bedrijfskritische installaties heeft uitgevoerd. Dit kanaal is alleen beschikbaar voor klanten en levert het Nextcloud Enterprise pakket.",
    "Stable" : "Stabiel",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "De meest recente stabiele versie. Het is geschikt voor normaal gebruik en werkt altijd bij naar de laatste hoofdversie.",
    "Beta" : "Test",
    "A pre-release version only for testing new features, not for production environments." : "Een vroeg vrijgegeven versie alleen voor het testen van nieuwe functies, niet voor produktie omgevingen.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> app heeft geen update voor deze versie beschikbaar","<strong>%n</strong> apps hebben geen update voor deze versie beschikbaar"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Je kunt altijd updaten naar een nieuwere versie of experimenteel kanaal. Maar terug naar een oudere versie of een stabieler kanaal is niet mogelijk.",
    "<strong>production</strong> will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2)." : "<strong>productie</strong> heeft altijd de laatste patches, maar de verwerkt de update naar de volgende grote release nog niet onmiddellijk.  Die update gebeurt meestal bij de tweede kleine release (x.0.2).",
    "<strong>stable</strong> is the most recent stable version. It is suited for regular use and will always update to the latest major version." : "<strong>stable</strong> is de recentste stabiele versie.  Het is geschikt voor regulier gebruik en zal altijd bijwerken naar de laatste grote versie.",
    "<strong>beta</strong> is a pre-release version only for testing new features, not for production environments." : "<strong>bèta</strong> is een versie om nieuwe functies uit te proberen, niet om te gebruiken in een productieomgeving.",
    "Production" : "Productie",
    "Will always provide the latest patch level, but not update to the next major release immediately. That update usually happens with the second minor release (x.0.2) and only if the instance is already on the latest minor version." : "Geeft altijd de laatste aanpassingen, maar zal niet onmiddellijk naar de volgende hoofdversie gaan. Dat gebeurt wanneer de tweede sub versie (x.0.2) vrijgegeven wordt en alleen wanneer de huidige versie ook al op de laatste sub versie is."
},
"nplurals=2; plural=(n != 1);");
